@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckReference;
 # ABSTRACT: Git::Hooks plugin for checking references
-$Git::Hooks::CheckReference::VERSION = '2.0.1';
+$Git::Hooks::CheckReference::VERSION = '2.1.0';
 use 5.010;
 use utf8;
 use strict;
@@ -65,7 +65,7 @@ Git::Hooks::CheckReference - Git::Hooks plugin for checking references
 
 =head1 VERSION
 
-version 2.0.1
+version 2.1.0
 
 =head1 DESCRIPTION
 
@@ -115,8 +115,8 @@ branches with names prefixed by F<feature/>, F<release/>, and F<hotfix/>,
 denying all others.
 
     [githooks "checkreference"]
-        deny  ^refs/heads/
-        allow ^refs/heads/(?:feature|release|hotfix)/
+        deny  = ^refs/heads/
+        allow = ^refs/heads/(?:feature|release|hotfix)/
 
 Note that the order of the directives is irrelevant.
 
